@@ -11,7 +11,7 @@ no warnings qw( void once uninitialized );
 	our @ISA = 'Exporter';
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.007';
+	our $VERSION   = '0.008';
 	our @EXPORT    = qw( boolean );
 	our (%LANG, @LANG);
 	our @BASELANG  = qw( zh en es hi ru ar pt bn fr ms de ja );
@@ -59,7 +59,7 @@ no warnings qw( void once uninitialized );
 	package Lingua::Boolean::Tiny::BASE;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.007';
+	our $VERSION   = '0.008';
 	
 	# Versions of ~~ and fc for legacy Perls...
 	use if $] >= 5.016, feature => 'fc';
@@ -156,7 +156,7 @@ no warnings qw( void once uninitialized );
 	package Lingua::Boolean::Tiny::Union;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.007';
+	our $VERSION   = '0.008';
 	
 	sub new
 	{
@@ -252,8 +252,8 @@ no warnings qw( void once uninitialized );
 	[
 		German => [qw( de deu ger )],
 		qw( ja nein ),
-		[qr{^[jJyY].*}, qr{^ja?$}i],
-		[qr{^[nN].*}, qr{^n(?:ein)?$}i, qr{^y}i],
+		[qr{^[jJyY].*}, qr{^ja?$}i, qr{^wahr$}i],
+		[qr{^[nN].*}, qr{^n(?:ein)?$}i, qr{^falsche$}i],
 	],
 	[
 		Japanese => [qw( ja jpn )],
